@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2020 openpyxl
+# Copyright (c) 2010-2022 openpyxl
 
 import atexit
 from collections import defaultdict
@@ -263,7 +263,7 @@ class WorksheetWriter:
     def write_tables(self):
         tables = TablePartList()
 
-        for table in self.ws._tables.values():
+        for table in self.ws.tables.values():
             if not table.tableColumns:
                 table._initialise_columns()
                 if table.headerRowCount:
